/*
 * Copyright (c) 2018 Razeware LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * Notwithstanding the foregoing, you may not use, copy, modify, merge, publish,
 * distribute, sublicense, create a derivative work, and/or sell copies of the
 * Software in any work that is designed, intended, or marketed for pedagogical or
 * instructional purposes related to programming, coding, application development,
 * or information technology.  Permission for such use, copying, modification,
 * merger, publication, distribution, sublicensing, creation of derivative works,
 * or sale is expressly withheld.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
 
package com.raywenderlich.iwatch.data

import android.app.Application
import android.arch.lifecycle.LiveData
import android.arch.lifecycle.MutableLiveData
import android.util.Log
import com.raywenderlich.iwatch.data.db.MovieDao
import com.raywenderlich.iwatch.data.db.MovieDatabase
import com.raywenderlich.iwatch.data.model.Movie
import com.raywenderlich.iwatch.data.model.MoviesResponse
import com.raywenderlich.iwatch.data.net.RetrofitClient
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response
import kotlin.concurrent.thread

class MovieRepository(application: Application) {

  private val movieDao: MovieDao
  private val retrofitClient = RetrofitClient()

  init {
    val movieDatabase = MovieDatabase.getInstance(application)
    movieDao = movieDatabase.movieDao()
  }

  fun getSavedMovies(): LiveData<List<Movie>> {
    return movieDao.getAll()
  }

  fun saveMovie(movie: Movie) {
    thread {
      movieDao.insert(movie)
    }
  }

  fun updateMovie(movie: Movie) {
    thread {
      movieDao.updateMovie(movie)
    }
  }

  fun deleteWatchedMovies() {
    thread {
      movieDao.deleteMovies(true)
    }
  }
  fun searchMovies(query: String): LiveData<List<Movie>> {
    val data = MutableLiveData<List<Movie>>()
    retrofitClient.searchMovies(query).enqueue(object : Callback<MoviesResponse> {

      override fun onFailure(call: Call<MoviesResponse>, t: Throwable) {
        Log.d(javaClass.simpleName, "Remember to add your KEY in your RetrofitClient.kt file")
      }

      override fun onResponse(call: Call<MoviesResponse>, response: Response<MoviesResponse>) {
        if (response.isSuccessful) {
          val movies = response.body()?.results
          data.value = movies
        }
      }
    })
    return data
  }
}
